#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 STMonadTrans
version:              0.4.8.1
visibility:           public
id:                   STMonadTrans-0.4.8.1-KVii5qZntAD9VUgPU4pGAz
key:                  STMonadTrans-0.4.8.1-KVii5qZntAD9VUgPU4pGAz
license:              BSD-3-Clause
maintainer:           Andreas Abel, josef.svenningsson@gmail.com
author:               Josef Svenningsson
homepage:             https://github.com/josefs/STMonadTrans
synopsis:             A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad.

    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.

category:             Monads
abi:                  157b51923d8ca449b3dbecb06b11dcbf
exposed:              True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/STMonadTrans-0.4.8.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/STMonadTrans-0.4.8.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/STMonadTrans-0.4.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stmonadtrans
hs-libraries:         HSSTMonadTrans-0.4.8.1-KVii5qZntAD9VUgPU4pGAz
depends:              array-0.5.6.0 base-4.18.2.1 mtl-2.3.1
haddock-interfaces:
    /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock

haddock-html:         /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

